@@ -168,11 +168,15 @@ def manage_jobpool(jobdict, seed_names, seed_spec, weight_dir, tmp_path, cores,
         missinseq = []
         for i in missing:
             missinseq.append('>' + i + '\n' + fasta[seed_spec][i])
-        doAnnoForMissing(seed_spec, missinseq, weight_dir + "/" + seed_spec + ".json", tmp_path + "/", cores, True, annoToolFile)
+        doAnnoForMissing(seed_spec, missinseq, weight_dir + "/" + seed_spec + ".json", tmp_path + "/", cores, True,
+                         annoToolFile)
         tmp_data = read_json(tmp_path + "/" + seed_spec + ".json")
         seed_weight = w_weight_correction("loge", tmp_data["count"])
         seed_proteome = tmp_data["feature"]
     clan_dict = tmp_data["clan"]
+    interprokeys = {}
+    if 'inteprotID' in tmp_data:
+        interprokeys.update(tmp_data['inteprotID'])
     data = []
     for spec in jobdict:
         data.append([spec,
@@ -185,7 +189,7 @@ def manage_jobpool(jobdict, seed_names, seed_spec, weight_dir, tmp_path, cores,
                      "pairwise": jobdict[spec], "weight_correction": "loge", "outpath": tmp_path + "/" + spec,
                      "input_linearized": features[0], "input_normal": features[1], "MS_uni": 0,
                      "ref_proteome": [spec + '.json'], "progress": False},
-                     seed_proteome, seed_weight, weight_dir, clan_dict, fasta, tmp_path])
+                     seed_proteome, seed_weight, weight_dir, clan_dict, fasta, tmp_path, interprokeys])
     jobpool = multiprocessing.Pool(processes=cores)
     results = []
     for _ in tqdm(jobpool.imap_unordered(run_fas, data), total=len(jobdict)):
@@ -228,12 +232,14 @@ def run_fas(data):
         tmp_data = read_json(data[7] + "/" + data[0] + ".json")
         for i in missing:
             query_proteome[i] = tmp_data["feature"][i]
-
+    interprokeys = data[8]
+    if 'inteprotID' in tmp_data:
+        interprokeys.update(tmp_data['inteprotID'])
     clan_dict = data[5]
     clan_dict.update(tmp_data["clan"])
     seed_proteome = data[2]
     weight = w_weight_correction("loge", tmp_data["count"])
-    f_results = greedyFAS.fc_main(weight, seed_proteome, query_proteome, clan_dict, data[1])
+    f_results = greedyFAS.fc_main(weight, seed_proteome, query_proteome, clan_dict, data[1], interprokeys)
     outdata = {}
     for result in f_results:
         outdata[result[0], result[1]] = (result[2][0], 0.0)
@@ -243,7 +249,7 @@ def run_fas(data):
         for pair in data[1]['pairwise']:
             pairtmp.append((pair[1], pair[0]))
         data[1]['pairwise'] = pairtmp
-        r_results = greedyFAS.fc_main(data[3], query_proteome, seed_proteome, clan_dict, data[1])
+        r_results = greedyFAS.fc_main(data[3], query_proteome, seed_proteome, clan_dict, data[1], interprokeys)
         for result in r_results:
             outdata[result[1], result[0]] = (outdata[result[1], result[0]][0], result[2][0])
     return outdata, data[0]
