@@ -84,7 +84,7 @@ def download_data(file, checksum, toolPath):
             print('Extracting %s ...' % file)
             shutil.unpack_archive(file, toolPath, 'gztar')
         else:
-            sys.exit('Downloaded file corrupted!')
+            sys.exit('ERROR: Downloaded file corrupted!')
     else:
         sys.exit('Cannot download annotation tools!')
 
@@ -111,10 +111,18 @@ def query_yes_no(question, default='yes'):
                              '(or "y" or "n").\n')
 
 
+def check_conda_env():
+    """ Return if a conda env is currently using """
+    if 'CONDA_DEFAULT_ENV' in os.environ:
+        if not os.environ['CONDA_DEFAULT_ENV'] == 'base':
+            return(True)
+    return(False)
+
+
 def get_dtu_path(dtuPathIn):
     if not dtuPathIn == '':
         if not os.path.isdir(dtuPathIn):
-            sys.exit(dtuPathIn + ' not found!')
+            sys.exit('ERROR: ' + dtuPathIn + ' not found!')
         else:
             dtu_path = os.path.abspath(dtuPathIn)
     else:
@@ -133,9 +141,9 @@ def get_dtu_path(dtuPathIn):
         signalp_source = [i for i in files if 'signalp' in i]
         tmhmm_source = [i for i in files if 'tmhmm' in i]
         if not tmhmm_source:
-            sys.exit('TMHMM not found in %s' % dtu_path)
+            sys.exit('ERROR: TMHMM not found in %s' % dtu_path)
         if not signalp_source:
-            sys.exit('signalp-4.1g not found in %s' % dtu_path)
+            sys.exit('ERROR: signalp-4.1g not found in %s' % dtu_path)
         return dtu_path, signalp_source[0], tmhmm_source[0]
     else:
         return 0, 0, 0
@@ -155,7 +163,7 @@ def check_status(toolPath, force, tarfile):
                         try:
                             shutil.rmtree(toolPath)
                         except:
-                            sys.exit('Failed to delete %s. Please manually remove it and run fas.setup again!'
+                            sys.exit('ERROR: Failed to delete %s. Please manually remove it and run fas.setup again!'
                                      % toolPath)
                         if os.path.exists(os.path.abspath(cwd + '/' + tarfile)):
                             shutil.move(cwd + '/' + tarfile, toolPath + '/' + tarfile)
@@ -180,8 +188,6 @@ def install_signalp():
             outfile.write(line)
     shutil.move(signalp_path+'/signalp.mod', signalp_path+'/signalp')
     subprocess.call(['chmod', '0755', signalp_path+'/signalp'])
-    # makelink_signalp = 'ln -s -f bin/signalp signalp' # for signalp 5.0
-    # subprocess.call([makelink_signalp], shell=True)
 
 
 def install_tmhmm():
@@ -192,30 +198,82 @@ def install_tmhmm():
     subprocess.call([makelink_tmhmm], shell=True)
 
 
-def write_coilsdir(coilsdir):
-    home = str(Path.home())
-    filename = home + '/.bashrc'
-    if platform == 'darwin':
-        filename = home + '/.bash_profile'
-    with open(filename, "r+") as file:
-        for line in file:
-            if coilsdir in line:
-                break
+def install_smart(smart_path, anno_path):
+    check = glob.glob('%s/hmm/*.HMM' % smart_path)
+    if len(check) < 1:
+        return(0)
+    else:
+        Path(anno_path + '/SMART/SMART-hmms').mkdir(parents=True, exist_ok=True)
+        catCmd = 'cat %s/hmm/*.HMM > %s/SMART/SMART-hmms/SMART.hmm' % (smart_path, anno_path)
+        subprocess.call([catCmd], shell=True)
+        hmmpressCmd = 'hmmpress -f %s/SMART/SMART-hmms/SMART.hmm' % (anno_path)
+        try:
+            subprocess.run([hmmpressCmd], shell=True, check=True)
+        except:
+            print('ERROR: Problem occurred while creating binary files for SMART at %s/SMART/SMART-hmms' % (anno_path))
+        getVersionCmd = 'tail -n 1 %s/README | cut -d " " -f2 | sed "s/\//_/g" > %s/SMART/version.txt' % (smart_path, anno_path)
+        subprocess.call([getVersionCmd], shell=True)
+        return(1)
+
+def install_pfam(pfam_version, anno_path):
+    url = 'https://ftp.ebi.ac.uk/pub/databases/Pfam/releases/Pfam%s' % pfam_version
+    file = 'Pfam-A.hmm.gz'
+    dat_file = 'Pfam-A.hmm.dat.gz'
+    relnotes_file = 'relnotes.txt'
+    download_file(url, file)
+    download_file(url, dat_file)
+    download_file(url, relnotes_file)
+    if os.path.isfile(file):
+        Path(anno_path + '/Pfam/Pfam-hmms').mkdir(parents=True, exist_ok=True)
+        # move donwloaded file to anno_path/Pfam/Pfam-hmms
+        try:
+            shutil.move(file, '%s/Pfam/Pfam-hmms/%s' % (anno_path, file))
+            shutil.move(dat_file, '%s/Pfam/Pfam-hmms/%s' % (anno_path, dat_file))
+            shutil.move(relnotes_file, '%s/Pfam/Pfam-hmms/%s' % (anno_path, relnotes_file))
+        except:
+            sys.exit('ERROR: Cannot move %s, %s & %s to %s/Pfam/Pfam-hmms' % (file, dat_file, relnotes_file, anno_path))
+        # unzip downloaded files
+        unzipCmd = 'gzip -d %s/Pfam/Pfam-hmms/*.gz' % anno_path
+        try:
+            subprocess.run([unzipCmd], shell=True, check=True)
+        except:
+            sys.exit('ERROR: Cannot upzip gz files in %s/Pfam/Pfam-hmms' % anno_path)
+        # create bin files for Pfam-A.hmm
+        hmmpressCmd = 'hmmpress -f %s/Pfam/Pfam-hmms/Pfam-A.hmm' % (anno_path)
+        try:
+            subprocess.run([hmmpressCmd], shell=True, check=True)
+        except:
+            sys.exit('ERROR: Problem occurred while creating binary files for PFAM at %s/Pfam/Pfam-hmms' % (anno_path))
+    else:
+        sys.exit('ERROR: No Pfam-A.hmm.gz found at %s' % url)
+
+
+def check_hmmer():
+    try:
+        subprocess.check_output(['which hmmsearch'], shell = True, stderr = subprocess.STDOUT)
+    except subprocess.CalledProcessError as e:
+        if check_conda_env() == True:
+            conda_install_cmd = 'conda install -c bioconda hmmer -y'
+            try:
+                subprocess.call([conda_install_cmd], shell = True)
+            except:
+                sys.exit('\033[91mERROR: Cannot install hmmer using this command\n%s\033[0m' % conda_install_cmd)
         else:
-            file.write(coilsdir)
+            sys.exit('\033[91mERROR: Please install HMMER before using FAS (http://hmmer.org/documentation.html)\033[0m')
 
 
-def prepare_annoTool(options):
+def install_annoTool(options):
     anno_path = options['toolPath']
     dtuPathIn = options['dtuPath']
+    smart_path = options['smartPath']
     force = options['force']
     ignoreList = options['ignore']
+    pfam_version = options['pfamVersion']
+    check_hmmer()
 
     file = 'annotation_FAS2020d.tar.gz'
     checksum = '1818703744 1108970315 ' + file
 
-    if options['disorder']:
-        install_aucpred.install_auc(options['toolPath'])
     if os.path.exists(os.path.abspath(anno_path+'/annoTools.txt')):
         with open(anno_path+'/annoTools.txt') as checkfile:
             if '#checked' in checkfile.read():
@@ -236,7 +294,7 @@ def prepare_annoTool(options):
         print('Annotation tools will be installed in ')
         print(os.getcwd())
         print('----------------------------------')
-        defaultTools = ['fLPS', 'Pfam', 'SMART', 'COILS2', 'SEG'] #, 'SignalP', 'TMHMM']
+        defaultTools = ['fLPS', 'Pfam', 'COILS2', 'SEG']
         if platform == 'darwin':
             ignoreList.extend(('SEG', 'TMHMM'))
         tools = [tool for tool in defaultTools if tool not in ignoreList]
@@ -265,9 +323,19 @@ def prepare_annoTool(options):
                     os.chdir(anno_path)
                     tools.append('TMHMM')
 
+        # install SMART
+        smart = 0
+        if not smart_path == '':
+            print('Installing SMART...')
+            smart = install_smart(smart_path, anno_path)
+            if smart == 0:
+                print('ERROR: Failed to install SMART from %s' % smart_path)
+
         # close annoTools file
         with open('annoTools.txt', mode='wt') as tool_file:
-            tool_file.write('#linearized\nPfam\nSMART\n#normal\n')
+            tool_file.write('#linearized\nPfam\n#normal\n')
+            if (smart == 1):
+                tool_file.write('#linearized\nPfam\nSMART\n#normal\n')
             for t in tools:
                 if not t in ['Pfam','SMART']:
                     tool_file.write('%s\n' % t)
@@ -275,6 +343,9 @@ def prepare_annoTool(options):
 
         # download other annotation tools
         print('Installing other tools...')
+        if options['disorder']:
+            install_aucpred.install_auc(options['toolPath'])
+
         if os.path.isfile(file):
             checksum_file = subprocess.check_output(['cksum', file]).decode(sys.stdout.encoding).strip()
             if checksum_file == checksum:
@@ -290,11 +361,12 @@ def prepare_annoTool(options):
         for tool in tools:
             if tool == 'fLPS':
                 print('Downloading fLPS ...')
-                fLPS_file = 'fLPS.tar.gz'
+                fLPS_file = 'fLPS2programs.tar' #'fLPS.tar.gz'
                 fLPS_url = 'http://biology.mcgill.ca/faculty/harrison/'
                 download_file(fLPS_url, fLPS_file)
                 shutil.unpack_archive(fLPS_file, anno_path, 'gztar')
                 os.remove(fLPS_file)
+                shutil.move('fLPS2programs', 'fLPS')
             else:
                 if not tool in ('SignalP', 'TMHMM'):
                     print('Moving %s ...' % tool)
@@ -303,23 +375,27 @@ def prepare_annoTool(options):
                         shutil.rmtree(anno_path + '/' + tool)
                     shutil.move(source_dir, anno_path, copy_function=shutil.copytree)
 
-        # make symlink for fLPS (depend on OS system)
-        source = os.getcwd() + '/fLPS/bin'
-        target = os.getcwd() + '/fLPS/fLPS'
-        if platform == 'darwin':
-            source = source + '/mac64/fLPS'
-            try:
-                os.symlink(source, target)
-            except FileExistsError:
-                os.remove(target)
-                os.symlink(source, target)
-        else:
-            source = source + '/linux/fLPS'
+        # replace PFAM by user-defined version
+        if not pfam_version == '':
+            print('Downloading Pfam version %s...' % pfam_version)
+            shutil.rmtree(anno_path + '/Pfam')
+            install_pfam(pfam_version, anno_path)
+
+        # compile and make symlink for fLPS
+        flps_path = anno_path + '/fLPS'
+        os.chdir(flps_path + '/src')
+        makeCmd = 'make'
+        try:
+            subprocess.call([makeCmd], shell=True)
+            source = flps_path + '/src/fLPS2'
+            target = flps_path + '/fLPS'
             try:
                 os.symlink(source, target)
             except FileExistsError:
                 os.remove(target)
                 os.symlink(source, target)
+        except:
+            print('ERROR: Failed to compile fLPS.\nPlease try to do it manually at' % flps_path)
 
         if not 'COILS2' in ignoreList:
             # re-compile COILS2
@@ -333,18 +409,14 @@ def prepare_annoTool(options):
                 subprocess.call(compile_cmd, shell=True)
             except:
                 print('ERROR: Failed to compile COILS2.\nPlease read instruction at %s and do it manually!' % coils_path)
-            COILSDIR = 'export COILSDIR=%s\n' % coils_bin
-            write_coilsdir(COILSDIR)
             os.chdir(coils_path)
             if os.path.exists('COILS2'):
                 os.remove('COILS2')
             os.symlink('coils/ncoils-osf', './COILS2')
-            home = str(Path.home())
-            if platform == 'darwin':
-                os.system('. %s/.bash_profile' % home)
-            else:
-                os.system('. %s/.bashrc' % home)
             os.chdir(anno_path)
+            COILSDIR = 'export COILSDIR=%s\n' % coils_bin
+            with open(anno_path + '/fas.profile', 'w') as outfile:
+                outfile.write(COILSDIR)
         print('----------------------------------')
         # remove temp files
         shutil.rmtree(anno_path + '/annotation_FAS')
@@ -367,8 +439,9 @@ def checkExecutable(anno_path):
     # test pfam and smart
     if not os.path.isfile(anno_path + '/Pfam/Pfam-hmms/Pfam-A.hmm'):
         sys.exit('Pfam hmm file not found. Please run fas.setup with --force!')
-    if not os.path.isfile(anno_path + '/SMART/SMART-hmms/SMART.hmm'):
-        sys.exit('SMART hmm file not found. Please run fas.setup with --force!')
+    if 'SMART' in availTool:
+        if not os.path.isfile(anno_path + '/SMART/SMART-hmms/SMART.hmm'):
+            sys.exit('SMART hmm file not found. Please run fas.setup with --force!')
     # test seg
     if 'SEG' in availTool:
         segCmd = '%s/SEG/seg' % anno_path
@@ -385,36 +458,15 @@ def checkExecutable(anno_path):
         try:
             p2 = subprocess.Popen([flpsCmd], stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
             output2, err2 = p2.communicate()
-            if not err2.decode('UTF-8').strip() == 'There is no sequence file. Please supply one.':
+            if not err2.decode('UTF-8').strip() == 'There is no sequence file. Please supply one in FASTA format.': # 'There is no sequence file. Please supply one.':
                 sys.exit('Error with fLPS. You can reinstall it by running fas.setup with --force!')
         except:
             sys.exit('Error with fLPS. You can reinstall it by running fas.setup with --force!')
     # test COILS2
     if 'COILS2' in availTool:
-        coilsCmd = '%s/COILS2/COILS2' % anno_path
-        try:
-            flag = 1
-            p3 = subprocess.Popen([coilsCmd], stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-            output3, err3 = p3.communicate()
-            if err3.decode('UTF-8').strip() == 'Error reading '+os.getcwd()+'/new.mat':
-                flag = 0
-            if err3.decode('UTF-8').strip() == 'error: environment variable COILSDIR must be set':
-                home = str(Path.home())
-                bash_file = '.bashrc'
-                if platform == 'darwin':
-                    bash_file = '.bash_profile'
-                with open(home + '/' + bash_file) as file:
-                    if not 'export COILSDIR' in file.read():
-                        print("PLEASE PUT THE FOLLOWING LINE TO %s/%s:\nexport COILSDIR=%s" %
-                              (home, bash_file, anno_path + '/COILS2/coils'))
-                print('NOTE: THE TERMINAL MUST BE RESTARTED BEFORE USING FAS!!!')
-                flag = 0
-            if '0 sequences' in err3.decode('UTF-8').strip():
-                flag = 0
-            if flag == 1:
-                sys.exit('Error with COILS2. Please restart the terminal and run fas.setup again with --checkExecutable!')
-        except:
-            sys.exit('Error with COILS2. Please check https://github.com/BIONF/FAS/wiki/FAQ#Error-with-COILS2!')
+        profileFile = '%s/fas.profile' % anno_path
+        if not os.path.isfile(profileFile):
+            sys.exit('No config file for COILSDIR found. Please check https://github.com/BIONF/FAS/wiki/FAQ#Error-with-COILS2!')
     # test tmhmm
     if 'TMHMM' in availTool:
         tmhmmCmd = '%s/TMHMM/decodeanhmm' % anno_path
@@ -462,6 +514,8 @@ def saveConfigFile(checkResult, anno_path, greedyFasPath):
         print('Done! Annotation tools can be found in %s' % anno_path)
         print('You should test fas.doAnno with this command:')
         print('fas.doAnno -i test_annofas.fa -o testFas_output')
+        print('NOTE: YOU NEED TO source %s/fas.profile BEFORE USING FAS!' % anno_path)
+        print('Check https://github.com/BIONF/FAS/wiki/setup#add-COILSDIR-to-bashrc-or-bash_profile for more details')
         sys.exit()
     else:
         sys.exit('Some errors occur with annotation tools. Please check if they can be excuted at %s' % anno_path)
@@ -474,8 +528,10 @@ def main():
     optional = parser.add_argument_group('optional arguments')
     required.add_argument('-t', '--toolPath', help='Set path to save annotation tools', action='store', default='',
                           required=True)
+    optional.add_argument('--smartPath', help='Set path to your downloaded SMART folder', action='store', default='')
     optional.add_argument('-d', '--dtuPath', help='Set path to DTU tools (SignalP and TMHMM)', action='store',
                           default='')
+    optional.add_argument('--pfamVersion', help='Specify your own PFAM version. E.g. 28.0', action='store', default='')
     optional.add_argument('-i', '--ignore', help='List of tools should be ignored', nargs="*",
                         choices=['SignalP', 'TMHMM', 'COILS2', 'fLPS', 'SEG'],
                         action='store', default=[])
@@ -493,7 +549,9 @@ def main():
     greedyFasPath = os.path.realpath(__file__).replace('/setupFAS.py','')
     options = {
         'toolPath': args.toolPath,
+        'smartPath': args.smartPath,
         'dtuPath': args.dtuPath,
+        'pfamVersion': args.pfamVersion,
         'ignore': args.ignore,
         'force': args.force,
         'keep': args.keep,
@@ -528,9 +586,10 @@ def main():
         print('Annotation tools can be found at %s. FAS is ready to run!' % args.toolPath)
         print('You should test fas.doAnno with this command:')
         print('fas.doAnno -i test_annofas.fa -o testFas_output')
+        print('NOTE: For using FAS you need to source %s/fas.profile first!' % args.toolPath)
         sys.exit()
 
-    anno_path = prepare_annoTool(options)
+    anno_path = install_annoTool(options)
     allRun = checkExecutable(anno_path)
     saveConfigFile(allRun, anno_path, greedyFasPath)
 
